@@ -7,11 +7,6 @@ from . import HomeServerSetup
 class MainCommand(Command):
     """Installs bacchus.
 
-    Requires
-
-    - Valid DNS hostname registered in a supported provider
-    - NAT or direct exposure of the given machine's openvpn port (1194)
-
     install
         {dns-domain? : Domain (FQDN) for virtualhosts}
         {username? : Nextcloud first user's username}
